==> glade-0.6.3.tar.bz2: glade-0.6.3/glade/glade_gnomedblib.c <==
/*  Gtk+ User Interface Builder
 *  Copyright (C) 1998-1999  Damon Chaplin
 *  Copyright (C) 2001  Carlos Perell Marn <carlos@gnome-db.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "gladeconfig.h"

#ifdef USE_GNOME_DB

#include "glade.h"
#include "gbwidget.h"

/* I've commented this out to avoid warnings. */
/*gchar *libname = "GNOME 1.0";*/

GbWidget *gb_gnome_db_browser_init ();
GbWidget *gb_gnome_db_combo_init ();
GbWidget *gb_gnome_db_error_init ();
GbWidget *gb_gnome_db_errordlg_init ();
GbWidget *gb_gnome_db_grid_init ();
GbWidget *gb_gnome_db_list_init ();
GbWidget *gb_gnome_db_login_init ();
GbWidget *gb_gnome_db_logindlg_init ();
GbWidget *gb_gnome_db_report_init ();
GbWidget *gb_gnome_db_iconlist_init ();
GbWidget *gb_gnome_db_dsnconfig_init ();
GbWidget *gb_gnome_db_dataset_init ();

GbWidget * gb_gnome_db_list_init (); 
GbWidget *gb_gnome_db_report_init ();
GbWidget *gb_gnome_db_iconlist_init ();
GbWidget *gb_gnome_db_designer_init ();
GbWidget *gb_gnome_db_entry_init ();
GbWidget *gb_gnome_db_export_init ();
GbWidget *gb_gnome_db_label_init ();
GbWidget *gb_gnome_db_log_viewer_init ();
GbWidget *gb_gnome_db_report_init ();
GbWidget *gb_gnome_db_table_editor_init ();

static GladeWidgetInitData gnome_db[] = {
	{ "GnomeDbLogin",       gb_gnome_db_login_init },
        { "GnomeDbLoginDlg",    gb_gnome_db_logindlg_init },
        { "GnomeDbDsnConfig",   gb_gnome_db_dsnconfig_init },
        { "GnomeDbBrowser",     gb_gnome_db_browser_init },
        { "GnomeDbGrid",        gb_gnome_db_grid_init },
        { "GnomeDbDataset",     gb_gnome_db_dataset_init },
        { "GnomeDbCombo",       gb_gnome_db_combo_init },
        { "GnomeDbList",        gb_gnome_db_list_init },
        { "GnomeDbReport",      gb_gnome_db_report_init },
        { "GnomeDbIconList",    gb_gnome_db_iconlist_init },
        { "GnomeDbError",       gb_gnome_db_error_init },
        { "GnomeDbErrorDlg",    gb_gnome_db_errordlg_init }, 
	{ "GnomeDbDesigner",	gb_gnome_db_designer_init },
	{ "GnomeDbEntry",	gb_gnome_db_entry_init },
	{ "GnomeDbExport",	gb_gnome_db_export_init },
	{ "GnomeDbLabel",	gb_gnome_db_label_init },
	{ "GnomeDbLogviewer",	gb_gnome_db_log_viewer_init },
	{ "GnomeDbReport",	gb_gnome_db_report_init },
	{ "GnomeDbTableeditor",	gb_gnome_db_table_editor_init },
	{ NULL, NULL }  
};


static GladePaletteSectionData sections[] =
{
  { "Gnome DB", gnome_db },
  { NULL, NULL }
};


GladePaletteSectionData *get_gnome_db_widgets()
{
	return sections;
}

#endif

==> glade-1.1.2.tar.bz2: glade-1.1.2/glade/glade_gnomedblib.c <==
/*  Gtk+ User Interface Builder
 *  Copyright (C) 1998-1999  Damon Chaplin
 *  Copyright (C) 2001  Carlos Perell Marn <carlos@gnome-db.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "gladeconfig.h"

#ifdef USE_GNOME_DB

#include "glade.h"
#include "gbwidget.h"

/* I've commented this out to avoid warnings. */
/*gchar *libname = "GNOME 1.0";*/

GbWidget *gb_gnome_db_browser_init ();
GbWidget *gb_gnome_db_combo_init ();
GbWidget *gb_gnome_db_dsnconfig_init ();
GbWidget *gb_gnome_db_error_init ();
GbWidget *gb_gnome_db_errordlg_init ();
GbWidget *gb_gnome_db_grid_init ();
GbWidget *gb_gnome_db_list_init ();
GbWidget *gb_gnome_db_login_init ();
GbWidget *gb_gnome_db_logindlg_init ();
GbWidget *gb_gnome_db_table_editor_init ();

static GladeWidgetInitData gnome_db[] = {
        { "GnomeDbLoginDialog", gb_gnome_db_logindlg_init },
	{ "GnomeDbLogin",       gb_gnome_db_login_init },
        { "GnomeDbErrorDialog", gb_gnome_db_errordlg_init }, 
        { "GnomeDbError",       gb_gnome_db_error_init },

        { "GnomeDbDsnConfig",   gb_gnome_db_dsnconfig_init },
        { "GnomeDbBrowser",     gb_gnome_db_browser_init },
        { "GnomeDbGrid",        gb_gnome_db_grid_init },
        /*{ "GnomeDbDataset",     gb_gnome_db_dataset_init },*/
        { "GnomeDbCombo",       gb_gnome_db_combo_init },
        { "GnomeDbList",        gb_gnome_db_list_init },
        /*{ "GnomeDbReport",      gb_gnome_db_report_init },*/
        /*{ "GnomeDbIconList",    gb_gnome_db_iconlist_init },*/
	/*{ "GnomeDbDesigner",	gb_gnome_db_designer_init },*/
	/*{ "GnomeDbEntry",	gb_gnome_db_entry_init },*/
	/*{ "GnomeDbExport",	gb_gnome_db_export_init },*/
	/*{ "GnomeDbLabel",	gb_gnome_db_label_init },*/
	/*{ "GnomeDbLogviewer",	gb_gnome_db_log_viewer_init },*/
	/*{ "GnomeDbReport",	gb_gnome_db_report_init },*/
	{ "GnomeDbTableEditor",	gb_gnome_db_table_editor_init },
	{ NULL, NULL }  
};


static GladePaletteSectionData sections[] =
{
  { "Gnome _DB", gnome_db },
  { NULL, NULL }
};


GladePaletteSectionData *get_gnome_db_widgets()
{
	return sections;
}

#endif
